Learn R Programming

ropenaq (version 0.2.11)

aq_countries: Provides a simple listing of countries within the platform.

Description

Provides a simple listing of countries within the platform.

Usage

aq_countries(limit = 10000, page = NULL)

Arguments

limit

Change the number of results returned, max is 10000 by page. If no page value, then all results or limit * 100 (maximal number of pages) is returned.

page

The page of the results to query (max 100).

Value

A results data.frame (dplyr "tbl_df") with 3 columns:

  • the number of measures for a country ("count"),

  • the ISO 3166-1 alpha-2 code of the country ("code"),

  • and its name ("name").

and 2 attributes, a meta data.frame (dplyr "tbl_df") with 1 line and 5 columns:

  • the API name ("name"),

  • the license of the data ("license"),

  • the website url ("website"),

  • the queried page ("page"),

  • the limit on the number of results ("limit"),

  • the number of results found on the platform for the query ("found")

and a timestamp data.frame (dplyr "tbl_df") with the query time and the last time at which the data was modified on the platform.

Details

For queries involving a country argument, the code of the country, not its name, should be used.

Examples

Run this code
# NOT RUN {
countries <- aq_countries()
countries
# }

Run the code above in your browser using DataLab