A results data.frame (dplyr "tbl_df") with 3 columns:
the number of measures for a country ("count"),
the ISO 3166-1 alpha-2 code of the country ("code"),
and its name ("name").
and 2 attributes, a meta data.frame (dplyr "tbl_df") with 1 line and 5 columns:
the API name ("name"),
the license of the data ("license"),
the website url ("website"),
the queried page ("page"),
the limit on the number of results ("limit"),
the number of results found on the platform for the query ("found")
and a timestamp data.frame (dplyr "tbl_df") with the query time and the last time at which the data was modified on the platform.